# recorder protocol
TO_RECORD_LIST = 'to_record_list'
TO_SAVE_LIST = 'to_save_list'
DEVICE = 'device'
BEST_MODEL_SUFFIX = '_best.ckpt'
STEP_MODEL_SUFFIX = '_{}.ckpt'
LOAD_EXCEPT_FUNC = lambda x: x[7:]